// https://nuxt.com/docs/api/configuration/nuxt-config
export default defineNuxtConfig({
  devtools: { enabled: false },

  modules: [
    '@nuxt/content',
    '@nuxtjs/device',
    '@pinia/nuxt',
    'nuxt-directus',
    ['nuxt-mail', {
      message: {
        to: process.env.EMAIL,
      },
      smtp: {
        host: process.env.SMTP_HOST,
        port: process.env.SMTP_PORT,
        auth: {
          user: process.env.SMTP_USER,
          pass: process.env.SMTP_PASS,
        },
      },
    }],
  ],

  directus: {
    url: process.env.DIRECTUS_URL,
    token: process.env.DIRECTUS_TOKEN,
    autoFetch: true,
  },

  content: {
    renderer: {
      anchorLinks: { h4: false }
    }
  },

  css: [
    "~/assets/style/style.css",
  ],

  postcss: {
    plugins: {
      'postcss-import': {},
      'postcss-nested': {},
      'postcss-hexrgba': {},
    }
  },

  runtimeConfig: {
    public: {
      HNS: process.env.HNS,
      DNS: process.env.DNS,
    },
  },

  routeRules: {
    '/pricing': { redirect: '/#pricing' }
  },

  experimental: { appManifest: false },

  telemetry: false,
  compatibilityDate: '2024-08-10'
})